==> haskell-tasty-expected-failure-0.12.3-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-expected-failure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-expected-failure
version:              0.12.3
visibility:           public
id:                   tasty-expected-failure-0.12.3-LpdgouR097K5iM9tHRNKe6
key:                  tasty-expected-failure-0.12.3-LpdgouR097K5iM9tHRNKe6
license:              MIT
copyright:            2015 Joachim Breitner
maintainer:           mail@joachim-breitner.de
author:               Joachim Breitner
homepage:             http://github.com/nomeata/tasty-expected-failure
synopsis:             Mark tasty tests as failure expected
description:
    With the function '\''Test.Tasty.ExpectedFailure.expectFail'\'' in the provided module
    "Test.Tasty.ExpectedFailure", you can mark that you expect test cases to fail,
    and not to pass.

    This can for example be used for test-driven development: Create the tests,
    mark them with '\''Test.Tasty.ExpectedFailure.expectFail'\'', and you can still push
    to the main branch, without your continuous integration branch failing.

    Once someone implements the feature or fixes the bug (maybe unknowingly), the
    test suite will tell him so, due to the now unexpectedly passing test, and he
    can remove the '\''Test.Tasty.ExpectedFailure.expectFail'\'' marker.

    The module also provides '\''Test.Tasty.ExpectedFailure.ignoreTest'\'' to avoid
    running a test. Both funtions are implemented via the more general
    '\''Test.Tasty.ExpectedFailure.wrapTest'\'', which is also provided.

category:             Testing
abi:                  a8479e990339b5a807e221c8dfc13dd8
exposed:              True
exposed-modules:      Test.Tasty.ExpectedFailure
import-dirs:          /usr/lib/ghc-9.0.1/site-local/tasty-expected-failure-0.12.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/tasty-expected-failure-0.12.3
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/tasty-expected-failure-0.12.3

hs-libraries:         HStasty-expected-failure-0.12.3-LpdgouR097K5iM9tHRNKe6
depends:
    base-4.15.0.0 tagged-0.8.6.1-FL843C40q4d1DeuwYADr25
    tasty-1.4.1-2fDxyTcYl3lLm0ptr4dtyr
    unbounded-delays-0.1.1.1-AgNQX1ma4b0EuIeeVLayGc

haddock-interfaces:
    /usr/share/doc/haskell-tasty-expected-failure/html/tasty-expected-failure.haddock

haddock-html:         /usr/share/doc/haskell-tasty-expected-failure/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-expected-failure-0.12.3-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-expected-failure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-expected-failure
version:              0.12.3
visibility:           public
id:                   tasty-expected-failure-0.12.3-FtGxguhV8lNqHIfHRByAl
key:                  tasty-expected-failure-0.12.3-FtGxguhV8lNqHIfHRByAl
license:              MIT
copyright:            2015 Joachim Breitner
maintainer:           mail@joachim-breitner.de
author:               Joachim Breitner
homepage:             http://github.com/nomeata/tasty-expected-failure
synopsis:             Mark tasty tests as failure expected
description:
    With the function '\''Test.Tasty.ExpectedFailure.expectFail'\'' in the provided module
    "Test.Tasty.ExpectedFailure", you can mark that you expect test cases to fail,
    and not to pass.

    This can for example be used for test-driven development: Create the tests,
    mark them with '\''Test.Tasty.ExpectedFailure.expectFail'\'', and you can still push
    to the main branch, without your continuous integration branch failing.

    Once someone implements the feature or fixes the bug (maybe unknowingly), the
    test suite will tell him so, due to the now unexpectedly passing test, and he
    can remove the '\''Test.Tasty.ExpectedFailure.expectFail'\'' marker.

    The module also provides '\''Test.Tasty.ExpectedFailure.ignoreTest'\'' to avoid
    running a test. Both funtions are implemented via the more general
    '\''Test.Tasty.ExpectedFailure.wrapTest'\'', which is also provided.

category:             Testing
abi:                  9cb7da000cedf83f0a9de765fb8c87b7
exposed:              True
exposed-modules:      Test.Tasty.ExpectedFailure
import-dirs:          /usr/lib/ghc-9.0.1/site-local/tasty-expected-failure-0.12.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/tasty-expected-failure-0.12.3
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/tasty-expected-failure-0.12.3

hs-libraries:         HStasty-expected-failure-0.12.3-FtGxguhV8lNqHIfHRByAl
depends:
    base-4.15.0.0 tagged-0.8.6.1-FL843C40q4d1DeuwYADr25
    tasty-1.4.1-63a6ns6foxE106MSEf19dD
    unbounded-delays-0.1.1.1-AgNQX1ma4b0EuIeeVLayGc

haddock-interfaces:
    /usr/share/doc/haskell-tasty-expected-failure/html/tasty-expected-failure.haddock

haddock-html:         /usr/share/doc/haskell-tasty-expected-failure/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
